@@ -1,6 +1,6 @@
 """
-LEGION (https://gotham-security.com)
-Copyright (c) 2023 Gotham Security
+LEGION (https://shanewilliamscott.com)
+Copyright (c) 2025 Shane William Scott
 
     This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
     License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later
@@ -13,7 +13,7 @@ Copyright (c) 2023 Gotham Security
     You should have received a copy of the GNU General Public License along with this program.
     If not, see <http://www.gnu.org/licenses/>.
 
-Author(s): Shane Scott (sscott@gotham-security.com), Dmitriy Dubson (d.dubson@gmail.com)
+Author(s): Shane Scott (sscott@shanewilliamscott.com), Dmitriy Dubson (d.dubson@gmail.com)
 """
 from PyQt6 import QtCore
 
@@ -55,7 +55,7 @@ class PythonImporter(QtCore.QThread):
             session = self.db.session()
             startTime = time()
             self.db.dbsemaphore.acquire() # ensure that while this thread is running, no one else can write to the DB
-            #self.setPythonScript(self.pythonScript)
+            self.setPythonScript(self.pythonScript)
             db_host = session.query(hostObj).filter_by(ip = self.hostIp).first()
             self.pythonScriptObj.setDbHost(db_host)
             self.pythonScriptObj.setSession(session)
