@@ -1,6 +1,6 @@
 """
-LEGION (https://gotham-security.com)
-Copyright (c) 2023 Gotham Security
+LEGION (https://shanewilliamscott.com)
+Copyright (c) 2025 Shane William Scott
 
     This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
     License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later
@@ -13,8 +13,9 @@ Copyright (c) 2023 Gotham Security
     You should have received a copy of the GNU General Public License along with this program.
     If not, see <http://www.gnu.org/licenses/>.
 
-Author(s): Shane Scott (sscott@gotham-security.com), Dmitriy Dubson (d.dubson@gmail.com)
+Author(s): Shane Scott (sscott@shanewilliamscott.com), Dmitriy Dubson (d.dubson@gmail.com)
 """
+
 import os
 import logging
 from logging import Logger
@@ -57,14 +58,15 @@ def getOrCreateCachedLogger(logName: str, logPath: str, console: bool, cachedLog
     if cachedLogger:
         return cachedLogger
 
-    import logging
     from rich.logging import RichHandler
 
+    import sys
+    from rich.console import Console
     logging.basicConfig(
         level="INFO",
         format="%(message)s",
         datefmt="[%X]",
-        handlers=[RichHandler(rich_tracebacks=True)]
+        handlers=[RichHandler(rich_tracebacks=True, console=Console(file=sys.stderr))]
     )
 
     log = logging.getLogger("rich")
