@@ -1,6 +1,6 @@
 """
-LEGION (https://gotham-security.com)
-Copyright (c) 2023 Gotham Security
+LEGION (https://shanewilliamscott.com)
+Copyright (c) 2025 Shane William Scott
 
     This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
     License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later
@@ -13,13 +13,14 @@ Copyright (c) 2023 Gotham Security
     You should have received a copy of the GNU General Public License along with this program.
     If not, see <http://www.gnu.org/licenses/>.
 
-Author(s): Shane Scott (sscott@gotham-security.com), Dmitriy Dubson (d.dubson@gmail.com)
+Author(s): Shane Scott (sscott@shanewilliamscott.com), Dmitriy Dubson (d.dubson@gmail.com)
 """
 
 
-def getNmapRunningFolder(projectRunningFolder: str) -> str:
-    return f"{projectRunningFolder}/nmap"
+import os
 
+def getNmapRunningFolder(projectRunningFolder: str) -> str:
+    return os.path.normpath(os.path.join(projectRunningFolder, "nmap"))
 
 def getNmapOutputFolder(projectOutputFolder: str) -> str:
-    return f"{projectOutputFolder}/nmap"
+    return os.path.normpath(os.path.join(projectOutputFolder, "nmap"))
