@@ -21,7 +21,9 @@ import subprocess
 import tempfile
 import os
 import socket
+import re
 from PyQt6.QtCore import QTimer, QElapsedTimer, QVariant
+from PyQt6 import sip
 
 from app.ApplicationInfo import applicationInfo
 from app.Screenshooter import Screenshooter
@@ -30,6 +32,7 @@ from app.importers.NmapImporter import NmapImporter
 from app.importers.PythonImporter import PythonImporter
 from app.tools.nmap.NmapPaths import getNmapRunningFolder
 from app.auxiliary import unixPath2Win, winPath2Unix, getPid, formatCommandQProcess, isWsl
+from app.timing import getTimestamp
 from ui.observers.QtUpdateProgressObserver import QtUpdateProgressObserver
 import os
 
@@ -49,6 +52,62 @@ def normalize_path(path):
     return os.path.normpath(path).replace("\\", "/")
 
 class Controller:
+    def _resolve_host_and_ip(self, host_value: str):
+        display_host = host_value
+        ip_value = host_value
+        try:
+            repo_container = getattr(self.logic.activeProject, "repositoryContainer", None)
+            if repo_container and hasattr(repo_container, "hostRepository"):
+                host_repo = repo_container.hostRepository
+                host_obj = host_repo.getHostByIP(host_value)
+                if not host_obj:
+                    host_obj = host_repo.getHostByHostname(host_value)
+                if host_obj:
+                    hostname = getattr(host_obj, 'hostname', None)
+                    if hostname:
+                        display_host = hostname.strip()
+                    candidate_ip = getattr(host_obj, 'ip', None) or getattr(host_obj, 'ipv4', None)
+                    if candidate_ip:
+                        ip_value = candidate_ip.strip()
+        except Exception:
+            log.debug(f"Failed to resolve hostname for {host_value}", exc_info=True)
+        return display_host or host_value, ip_value or host_value
+
+    def _resolve_host_record(self, identifier: str):
+        """Return the hostObj matching the provided identifier (IP, hostname, or 'ip (hostname)')."""
+        repo_container = self.logic.activeProject.repositoryContainer
+        host_repo = getattr(repo_container, "hostRepository", None)
+        if not host_repo or not identifier:
+            return None
+
+        candidates = []
+        token = identifier.strip()
+        if token:
+            candidates.append(token)
+        if '(' in token and ')' in token:
+            prefix = token.split('(', 1)[0].strip()
+            suffix = token.split('(', 1)[1].strip(' )')
+            if prefix:
+                candidates.append(prefix)
+            if suffix:
+                candidates.append(suffix)
+
+        # Ensure uniqueness while preserving order
+        seen = set()
+        normalized_candidates = []
+        for cand in candidates:
+            if cand and cand not in seen:
+                normalized_candidates.append(cand)
+                seen.add(cand)
+
+        for cand in normalized_candidates:
+            host = host_repo.getHostByIP(cand)
+            if host:
+                return host
+            host = host_repo.getHostByHostname(cand)
+            if host:
+                return host
+        return None
     @staticmethod
     def _has_ipv6_connectivity():
         try:
@@ -309,9 +368,14 @@ class Controller:
         tool_output_dir = session_dir
         ipv6_flag = enableIPv6
 
+        target_hosts_str = str(targetHosts).strip()
+        if not target_hosts_str:
+            log.warning("addHosts: target host string is empty, skipping scan.")
+            return
+
         if scanMode == 'Easy':
             if runStagedNmap:
-                self.runStagedNmap(targetHosts, discovery=runHostDiscovery, enable_ipv6=ipv6_flag)
+                self.runStagedNmap(target_hosts_str, discovery=runHostDiscovery, enable_ipv6=ipv6_flag)
             elif runHostDiscovery:
                 outputfile = normalize_path(os.path.join(tool_output_dir, f"{getTimestamp()}-host-discover"))
                 easy_mode_flags = ['-f', '--data-length 5', '--randomize-hosts', '--max-retries 2']
@@ -328,10 +392,10 @@ class Controller:
                 command_tokens.extend(easy_mode_flags)
                 command_tokens.extend([
                     "-sV", "-O", "--version-light", f"-T{str(nmapSpeed)}",
-                    targetHosts, "--stats-every", "10s", "-oA", outputfile
+                    target_hosts_str, "--stats-every", "10s", "-oA", outputfile
                 ])
                 command = ' '.join(token for token in command_tokens if token)
-                self.runCommand('nmap', 'nmap (discovery)', targetHosts, '', '', command, getTimestamp(True),
+                self.runCommand('nmap', 'nmap (discovery)', target_hosts_str, '', '', command, getTimestamp(True),
                                 outputfile, self.view.createNewTabForHost(str(targetHosts), 'nmap (discovery)', True),
                                 enable_ipv6=ipv6_flag)
             else:
@@ -341,10 +405,10 @@ class Controller:
                     command_tokens.append("-6")
                 command_tokens.extend(nmapOptions)
                 command_tokens.extend([
-                    "-sL", f"-T{str(nmapSpeed)}", targetHosts, "--stats-every", "10s", "-oA", outputfile
+                    "-sL", f"-T{str(nmapSpeed)}", target_hosts_str, "--stats-every", "10s", "-oA", outputfile
                 ])
                 command = ' '.join(token for token in command_tokens if token)
-                self.runCommand('nmap', 'nmap (list)', targetHosts, '', '', command, getTimestamp(True),
+                self.runCommand('nmap', 'nmap (list)', target_hosts_str, '', '', command, getTimestamp(True),
                                 outputfile,
                                 self.view.createNewTabForHost(str(targetHosts), 'nmap (list)', True),
                                 enable_ipv6=ipv6_flag)
@@ -359,10 +423,10 @@ class Controller:
             options_str = ' '.join(options_tokens).strip()
             command_tokens = ["nmap"]
             command_tokens.extend(options_tokens)
-            command_tokens.extend([targetHosts, "--stats-every", "10s", "-oA", outputfile])
+            command_tokens.extend([target_hosts_str, "--stats-every", "10s", "-oA", outputfile])
             command = ' '.join(token for token in command_tokens if token)
             display_label = options_str
-            self.runCommand('nmap', 'nmap (custom ' + display_label + ')', targetHosts, '', '', command,
+            self.runCommand('nmap', 'nmap (custom ' + display_label + ')', target_hosts_str, '', '', command,
                             getTimestamp(True), outputfile,
                             self.view.createNewTabForHost(
                                 str(targetHosts), 'nmap (custom ' + display_label + ')', True),
@@ -501,15 +565,21 @@ class Controller:
     def handleServiceNameAction(self, targets, actions, action, restoring=True):
 
         if action.text() == 'Take screenshot':
-            for ip in targets:
-                url = ip[0] + ':' + ip[1]
-                self.screenshooter.addToQueue(ip[0], ip[1], url)
+            for target in targets:
+                host_value = str(target[0])
+                port_value = str(target[1])
+                display_host, resolved_ip = self._resolve_host_and_ip(host_value)
+                url = f"{display_host}:{port_value}"
+                self.screenshooter.addToQueue(resolved_ip, port_value, url)
             self.screenshooter.start()
             return
 
         elif action.text() == 'Open in browser':
-            for ip in targets:
-                url = ip[0]+':'+ip[1]
+            for target in targets:
+                host_value = str(target[0])
+                port_value = str(target[1])
+                display_host, _ = self._resolve_host_and_ip(host_value)
+                url = f"{display_host}:{port_value}"
                 self.browser.addToQueue(url)
             self.browser.start()
             return
@@ -593,20 +663,25 @@ class Controller:
             port_repo = repo_container.portRepository
             for t in targets:
                 ip, port, protocol, _ = t
-                host = host_repo.getHostByIP(ip)
-                if host:
-                    # Attempt to delete the port by host id, port, and protocol
-                    if hasattr(port_repo, "deletePortByHostIdAndPort"):
-                        port_repo.deletePortByHostIdAndPort(host.id, port, protocol)
-                    else:
-                        # Fallback: try to find and delete the port manually
-                        session = self.logic.activeProject.database.session()
+                host = self._resolve_host_record(ip)
+                if not host:
+                    log.warning(f"Delete Port: host '{ip}' could not be resolved.")
+                    continue
+                # Attempt to delete the port by host id, port, and protocol
+                if hasattr(port_repo, "deletePortByHostIdAndPort"):
+                    port_repo.deletePortByHostIdAndPort(host.id, port, protocol)
+                else:
+                    # Fallback: try to find and delete the port manually
+                    session = self.logic.activeProject.database.session()
+                    try:
                         port_obj = session.query(portObj).filter_by(
                             hostId=host.id, port=port, protocol=protocol
                         ).first()
                         if port_obj:
                             session.delete(port_obj)
                             session.commit()
+                    finally:
+                        session.close()
             self.view.updateInterface()
             return
 
@@ -617,9 +692,12 @@ class Controller:
             return
 
         if action.text() == 'Take screenshot':
-            for ip in targets:
-                url = f"{ip[0]}:{ip[1]}"
-                self.screenshooter.addToQueue(ip[0], ip[1], url)
+            for target in targets:
+                host_value = str(target[0])
+                port_value = str(target[1])
+                display_host, resolved_ip = self._resolve_host_and_ip(host_value)
+                url = f"{display_host}:{port_value}"
+                self.screenshooter.addToQueue(resolved_ip, port_value, url)
             self.screenshooter.start()
             return
 
@@ -646,6 +724,7 @@ class Controller:
     def getContextMenuForProcess(self):
         menu = QMenu()
         menu.addAction("Kill")
+        menu.addAction("Retry")
         menu.addAction("Clear")
         return menu
 
@@ -671,6 +750,63 @@ class Controller:
         if action.text() == 'Clear':  # hide all the processes that are not running
             self.logic.activeProject.repositoryContainer.processRepository.toggleProcessDisplayStatus()
             self.view.updateProcessesTableView()
+            return
+
+        if action.text() == 'Retry':
+            process_repo = self.logic.activeProject.repositoryContainer.processRepository
+            for pid, status, proc_id in selectedProcesses:
+                if status in ('Running', 'Waiting'):
+                    log.info(f"Process {proc_id} is currently {status}; skipping retry.")
+                    continue
+                process_details = process_repo.getProcessById(proc_id)
+                if not process_details:
+                    log.warning(f"Unable to locate process details for id {proc_id}; skipping retry.")
+                    continue
+                command = process_details.get('command')
+                if not command:
+                    log.warning(f"Process id {proc_id} has no recorded command; skipping retry.")
+                    continue
+                name = process_details.get('name') or 'process'
+                tab_title = process_details.get('tabTitle') or name
+                host_ip = process_details.get('hostIp') or ''
+                port = process_details.get('port') or ''
+                protocol = process_details.get('protocol') or ''
+                outputfile = process_details.get('outputfile') or ''
+
+                host_key = host_ip if host_ip else tab_title
+                textbox = self.view.createNewTabForHost(host_key, tab_title, False)
+
+                kwargs = {}
+                stage_match = re.search(r'stage\s*(\d+)', tab_title, re.IGNORECASE)
+                if stage_match:
+                    try:
+                        stage_number = int(stage_match.group(1))
+                    except ValueError:
+                        stage_number = 0
+                else:
+                    stage_number = 0
+
+                if stage_number:
+                    discovery_flag = '-Pn' not in command
+                    enable_ipv6_flag = '-6' in command
+                    kwargs['stage'] = stage_number
+                    kwargs['discovery'] = discovery_flag
+                    kwargs['enable_ipv6'] = enable_ipv6_flag
+
+                self.runCommand(
+                    name,
+                    tab_title,
+                    host_ip,
+                    str(port) if port is not None else '',
+                    protocol,
+                    command,
+                    getTimestamp(True),
+                    outputfile,
+                    textbox,
+                    **kwargs
+                )
+            self.view.updateProcessesTableView()
+            return
 
     #################### LEFT PANEL INTERFACE UPDATE FUNCTIONS ####################
 
@@ -855,13 +991,20 @@ class Controller:
 
     #################### BOTTOM PANEL INTERFACE UPDATE FUNCTIONS ####################
 
-    def getProcessesFromDB(self, filters, showProcesses='noNmap', sort='desc', ncol='id'):
-        return self.logic.activeProject.repositoryContainer.processRepository.getProcesses(filters, showProcesses, sort,
-                                                                                           ncol)
+    def getProcessesFromDB(self, filters, showProcesses='noNmap', sort='desc', ncol='id', status_filter=None):
+        return self.logic.activeProject.repositoryContainer.processRepository.getProcesses(
+            filters, showProcesses, sort, ncol, status_filter=status_filter
+        )
 
     def getProcessesForRestore(self):
         return self.logic.activeProject.repositoryContainer.processRepository.getProcessesForRestore()
 
+    def getOperatingSystemsSummary(self):
+        return self.logic.activeProject.repositoryContainer.hostRepository.getOperatingSystemsSummary()
+
+    def getHostsForOperatingSystem(self, os_name: str):
+        return self.logic.activeProject.repositoryContainer.hostRepository.getHostsByOperatingSystem(os_name)
+
     #################### PROCESSES ####################
 
     def checkProcessQueue(self):
@@ -1033,15 +1176,15 @@ class Controller:
 
         qProcess.sigHydra.connect(self.handleHydraFindings)
         qProcess.finished.connect(lambda: self.processFinished(qProcess))
-        qProcess.errorOccurred.connect(lambda: self.processCrashed(qProcess))
+        qProcess.errorOccurred.connect(lambda error, proc=qProcess: self.processCrashed(proc, error))
         log.info(f"runCommand called for stage {str(stage)}")
 
         if stage > 0 and stage < 6:  # if this is a staged nmap, launch the next stage
             log.info(f"runCommand connected for stage {str(stage)}")
             nextStage = stage + 1
             qProcess.finished.connect(
-                lambda host=str(hostIp), discovery_flag=discovery, next_stage=nextStage,
-                       enable_ipv6_flag=enable_ipv6, process_id=qProcess.id:
+                lambda exitCode, exitStatus, host=str(hostIp).strip(), discovery_flag=discovery,
+                       next_stage=nextStage, enable_ipv6_flag=enable_ipv6, process_id=qProcess.id:
                 self.runStagedNmap(
                     host,
                     discovery=discovery_flag,
@@ -1086,7 +1229,11 @@ class Controller:
     # recursive function used to run nmap in different stages for quick results
     def runStagedNmap(self, targetHosts, discovery=True, stage=1, stop=False, enable_ipv6=False):
         import os
-        log.info(f"runStagedNmap called for stage {str(stage)}")
+        host_arg = str(targetHosts).strip()
+        if not host_arg:
+            log.warning(f"runStagedNmap stage {stage}: empty target host received, aborting stage.")
+            return
+        log.info(f"runStagedNmap called for stage {str(stage)} targeting {host_arg}")
         runningFolder = self.logic.activeProject.properties.runningFolder
         # Use the session directory for temp files
         session_path = getattr(self.logic.activeProject, "sessionFile", None)
@@ -1097,7 +1244,7 @@ class Controller:
         # Use the tool output directory directly, not a subdirectory
         tool_output_dir = session_dir
         if not stop:
-            textbox = self.view.createNewTabForHost(str(targetHosts), 'nmap (stage ' + str(stage) + ')', True)
+            textbox = self.view.createNewTabForHost(host_arg, 'nmap (stage ' + str(stage) + ')', True)
             outputfile = os.path.join(tool_output_dir, f"{getTimestamp()}-nmapstage{str(stage)}")
 
             if stage == 1:
@@ -1112,9 +1259,9 @@ class Controller:
                 stageData = self.settings.tools_nmap_stage5_ports
             elif stage == 6:
                 stageData = self.settings.tools_nmap_stage6_ports
-            stageDataSplit = str(stageData).split('|')
+            stageDataSplit = str(stageData).split('|', maxsplit=1)
             stageOp = stageDataSplit[0]
-            stageOpValues = stageDataSplit[1]
+            stageOpValues = stageDataSplit[1] if len(stageDataSplit) > 1 else ''
             log.debug(f"Stage {str(stage)} stageOp {str(stageOp)}")
             log.debug(f"Stage {str(stage)} stageOpValues {str(stageOpValues)}")
 
@@ -1122,28 +1269,42 @@ class Controller:
                 log.debug(f"Skipping stage {str(stage)} as stageOp is {str(stageOp)}")
                 return
 
-            if discovery:                                           # is it with/without host discovery?
-                command = "nmap "
-                if enable_ipv6:
-                    command += "-6 "
-                command += "-T4 -sV -sSU -O "
+            command_tokens = ["nmap"]
+            if enable_ipv6:
+                command_tokens.append("-6")
+
+            if discovery:
+                command_tokens.extend(["-T4", "-sV", "-sSU", "-O"])
             else:
-                command = "nmap "
-                if enable_ipv6:
-                    command += "-6 "
-                command += "-Pn -sSU "
+                command_tokens.extend(["-Pn", "-sSU"])
 
+            stage_command_tokens = list(command_tokens)
             if stageOp == 'PORTS':
-                command += '-p ' + stageOpValues + ' -vvvv ' + targetHosts + ' -oA ' + outputfile
+                port_values = str(stageOpValues).strip()
+                if port_values:
+                    stage_command_tokens.extend(["-p", port_values])
+                stage_command_tokens.extend(["-vvvv", host_arg, "--stats-every", "10s", "-oA", outputfile])
             elif stageOp == 'NSE':
-                command = 'nmap '
+                stage_command_tokens = ["nmap"]
                 if enable_ipv6:
-                    command += '-6 '
-                command += '-sV --script=' + stageOpValues + ' -vvvv ' + targetHosts + ' --stats-every 10s -oA ' + outputfile
+                    stage_command_tokens.append("-6")
+                stage_command_tokens.extend([
+                    "-sV",
+                    f"--script={str(stageOpValues).strip()}",
+                    "-vvvv",
+                    host_arg,
+                    "--stats-every",
+                    "10s",
+                    "-oA",
+                    outputfile
+                ])
+            else:
+                stage_command_tokens.extend(["-vvvv", host_arg, "--stats-every", "10s", "-oA", outputfile])
 
+            command = ' '.join(token for token in stage_command_tokens if token)
             log.debug(f"Stage {str(stage)} command: {str(command)}")
 
-            self.runCommand('nmap', 'nmap (stage ' + str(stage) + ')', str(targetHosts), '', '', command,
+            self.runCommand('nmap', 'nmap (stage ' + str(stage) + ')', host_arg, '', '', command,
                             getTimestamp(True), outputfile, textbox, discovery=discovery, stage=stage, stop=stop,
                             enable_ipv6=enable_ipv6)
 
@@ -1175,22 +1336,35 @@ class Controller:
         #self.updateUITimer.stop()  # update the processes table
         #self.updateUITimer.start(900)
 
-    def processCrashed(self, proc):
+    def processCrashed(self, proc, error=None):
+        if proc is None or sip.isdeleted(proc):
+            log.warning("Received crash notification for a destroyed process object.")
+            return
         processRepository = self.logic.activeProject.repositoryContainer.processRepository
         processRepository.storeProcessCrashStatus(str(proc.id))
         log.info(f'Process {proc.id} Crashed!')
-        qProcessOutput = "\n\t" + str(proc.display.toPlainText()).replace('\n', '').replace("b'", "")
+        qProcessOutput = ""
+        if hasattr(proc, "display") and not sip.isdeleted(proc.display):
+            try:
+                qProcessOutput = "\n\t" + str(proc.display.toPlainText()).replace('\n', '').replace("b'", "")
+            except Exception:
+                qProcessOutput = ""
         # self.view.closeHostToolTab(self, index))
         self.view.findFinishedServiceTab(str(processRepository.getPIDByProcessId(str(proc.id))))
         log.info(f'Process {proc.id} Output: {qProcessOutput}')
-        log.info(f'Process {proc.id} Crash Output: {proc.errorString()}')
+        error_string = ""
+        try:
+            error_string = proc.errorString()
+        except Exception:
+            error_string = str(error) if error else ""
+        log.info(f'Process {proc.id} Crash Output: {error_string}')
         # --- User notification for scan crash ---
         from PyQt6.QtWidgets import QMessageBox
         msg = QMessageBox()
         msg.setIcon(QMessageBox.Icon.Critical)
         msg.setWindowTitle("Scan Crashed")
         msg.setText(
-            f"Scan process '{proc.name}' crashed!\n\nCommand: {proc.command}\n\nError: {proc.errorString()}\n\n"
+            f"Scan process '{proc.name}' crashed!\n\nCommand: {proc.command}\n\nError: {error_string}\n\n"
             "Check the log for more details."
         )
         msg.setStandardButtons(QMessageBox.StandardButton.Ok)
@@ -1349,22 +1523,20 @@ class Controller:
         for tool in self.settings.automatedAttacks:
             if service in tool[1].split(",") and protocol==tool[2]:
                 if tool[0] == "screenshooter":
-                    if hostname:
-                        url = hostname+':'+port
-                    else:
-                        url = ip+':'+port
+                    display_host, resolved_ip = self._resolve_host_and_ip(hostname or ip)
+                    url = f"{display_host}:{port}"
                     # Check if screenshot already exists using deterministic filename
                     screenshots_dir = os.path.join(self.logic.activeProject.properties.outputFolder, "screenshots")
-                    deterministic_screenshot = f"{ip}-{port}-screenshot.png"
+                    deterministic_screenshot = f"{resolved_ip}-{port}-screenshot.png"
                     screenshot_exists = False
                     if os.path.isdir(screenshots_dir):
                         if deterministic_screenshot in os.listdir(screenshots_dir):
                             screenshot_exists = True
                     if screenshot_exists:
-                        log.info(f"Skipping screenshot for {ip}:{port} (already exists)")
+                        log.info(f"Skipping screenshot for {resolved_ip}:{port} (already exists)")
                     else:
                         log.info("Screenshooter of URL: %s" % str(url))
-                        self.screenshooter.addToQueue(ip, port, url)
+                        self.screenshooter.addToQueue(resolved_ip, port, url)
                         self.screenshooter.start()
 
                 else:
@@ -1416,17 +1588,9 @@ class Controller:
         :param host_ip: IP address of the host (string)
         :param port_data: dict with keys 'port', 'state', 'protocol'
         """
-        repo_container = self.logic.activeProject.repositoryContainer
-        # Find host by IP using getHosts and filter
-        filters = self.view.viewState.filters
-        hosts = repo_container.hostRepository.getHosts(filters)
-        host = None
-        for h in hosts:
-            if hasattr(h, "ip") and h.ip == host_ip:
-                host = h
-                break
+        host = self._resolve_host_record(host_ip)
         if not host:
-            log.error(f"Host with IP {host_ip} not found.")
+            log.error(f"Host '{host_ip}' not found.")
             return
 
         # Create and add the port
@@ -1437,9 +1601,13 @@ class Controller:
             host_id = host.id
             new_port = portObj(port_id, protocol, state, host_id)
             session = self.logic.activeProject.database.session()
-            session.add(new_port)
-            session.commit()
-            log.info(f"Added port {port_id}/{protocol} ({state}) to host {host_ip}")
+            try:
+                session.add(new_port)
+                session.commit()
+            finally:
+                session.close()
+            host_label = getattr(host, 'hostname', '') or getattr(host, 'ip', '')
+            log.info(f"Added port {port_id}/{protocol} ({state}) to host {host_label}")
             self.view.updateInterface()
         except Exception as e:
             log.error(f"Failed to add port to host {host_ip}: {e}")
