@@ -1,6 +1,6 @@
 """
-LEGION (https://gotham-security.com)
-Copyright (c) 2023 Gotham Security
+LEGION (https://shanewilliamscott.com)
+Copyright (c) 2025 Shane William Scott
 
     This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
     License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later
@@ -13,7 +13,7 @@ Copyright (c) 2023 Gotham Security
     You should have received a copy of the GNU General Public License along with this program.
     If not, see <http://www.gnu.org/licenses/>.
 
-Author(s): Shane Scott (sscott@gotham-security.com), Dmitriy Dubson (d.dubson@gmail.com)
+Author(s): Shane Scott (sscott@shanewilliamscott.com), Dmitriy Dubson (d.dubson@gmail.com)
 """
 from sqlalchemy import Column, String, Integer
 from sqlalchemy.orm import relationship
@@ -40,6 +40,7 @@ class process(Base):
     output = relationship("process_output")
     status = Column(String)
     closed = Column(String)
+    percent = Column(String)  # New: percent complete for nmap scans
 
     def __init__(self, pid, *args):
         self.display = 'True'
@@ -57,4 +58,5 @@ class process(Base):
         self.status = args[9]
         self.closed = 'False'
         self.estimatedRemaining = args[11]
-        self.elapsed = args[12]
\ No newline at end of file
+        self.elapsed = args[12]
+        self.percent = args[13] if len(args) > 13 else None
