@@ -1,6 +1,6 @@
 """
-LEGION (https://gotham-security.com)
-Copyright (c) 2023 Gotham Security
+LEGION (https://shanewilliamscott.com)
+Copyright (c) 2025 Shane William Scott
 
     This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
     License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later
@@ -13,7 +13,7 @@ Copyright (c) 2023 Gotham Security
     You should have received a copy of the GNU General Public License along with this program.
     If not, see <http://www.gnu.org/licenses/>.
 
-Author(s): Shane Scott (sscott@gotham-security.com), Dmitriy Dubson (d.dubson@gmail.com)
+Author(s): Shane Scott (sscott@shanewilliamscott.com), Dmitriy Dubson (d.dubson@gmail.com)
 """
 
 from sqlalchemy import text
@@ -27,6 +27,15 @@ class PortRepository:
     def __init__(self, dbAdapter: Database):
         self.dbAdapter = dbAdapter
 
+    def getPortsByHostId(self, host_id):
+        """
+        Return all portObj ORM objects for a given host ID.
+        """
+        session = self.dbAdapter.session()
+        ports = session.query(portObj).filter_by(hostId=host_id).all()
+        session.close()
+        return ports
+
     def getPortsByIPAndProtocol(self, host_ip, protocol):
         session = self.dbAdapter.session()
         query = text("SELECT ports.portId FROM portObj AS ports INNER JOIN hostObj AS hosts ON hosts.id = ports.hostId "
@@ -50,9 +59,12 @@ class PortRepository:
                  "LEFT OUTER JOIN serviceObj AS services ON services.id = ports.serviceId WHERE hosts.ip = :host_ip")
         query += applyPortFilters(filters)
         query = text(query)
-        result = session.execute(query, {'host_ip': str(host_ip)}).fetchall()
+        result = session.execute(query, {'host_ip': str(host_ip)})
+        rows = result.fetchall()
+        keys = result.keys()
+        services = [dict(zip(keys, row)) for row in rows]
         session.close()
-        return result
+        return services
 
     # used to delete all port/script data related to a host - to overwrite portscan info with the latest scan
     def deleteAllPortsAndScriptsByHostId(self, hostID, protocol):
@@ -69,3 +81,28 @@ class PortRepository:
             session.delete(p)
         session.commit()
         session.close()
+
+    # delete a single port (and its scripts) by hostId, port, and protocol
+    def deletePortByHostIdAndPort(self, hostID, port, protocol):
+        session = self.dbAdapter.session()
+        port_entry = session.query(portObj)\
+            .filter(portObj.hostId == hostID)\
+            .filter(portObj.portId == str(port))\
+            .filter(portObj.protocol == str(protocol)).first()
+        if port_entry:
+            scripts_for_port = session.query(l1ScriptObj).filter(l1ScriptObj.portId == port_entry.id).all()
+            for s in scripts_for_port:
+                session.delete(s)
+            session.delete(port_entry)
+            session.commit()
+        session.close()
+
+    # fetch a single port by hostId, port, and protocol
+    def getPortByHostIdAndPort(self, hostID, port, protocol):
+        session = self.dbAdapter.session()
+        port_entry = session.query(portObj)\
+            .filter(portObj.hostId == hostID)\
+            .filter(portObj.portId == str(port))\
+            .filter(portObj.protocol == str(protocol)).first()
+        session.close()
+        return port_entry
