@@ -1,6 +1,6 @@
 """
-LEGION (https://gotham-security.com)
-Copyright (c) 2023 Gotham Security
+LEGION (https://shanewilliamscott.com)
+Copyright (c) 2025 Shane William Scott
 
     This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
     License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later
@@ -13,12 +13,13 @@ Copyright (c) 2023 Gotham Security
     You should have received a copy of the GNU General Public License along with this program.
     If not, see <http://www.gnu.org/licenses/>.
 
-Author(s): Shane Scott (sscott@gotham-security.com), Dmitriy Dubson (d.dubson@gmail.com)
+Author(s): Shane Scott (sscott@shanewilliamscott.com), Dmitriy Dubson (d.dubson@gmail.com)
 """
 from app.auxiliary import Filters
 from sqlalchemy import text
 from db.SqliteDbAdapter import Database
 from db.filters import applyFilters
+from db.entities.service import serviceObj
 
 
 class ServiceRepository:
@@ -34,9 +35,12 @@ class ServiceRepository:
         query += applyFilters(filters)
         query += ' ORDER BY service.name ASC'
         query = text(query)
-        result = session.execute(query).fetchall()
+        result = session.execute(query)
+        rows = result.fetchall()
+        keys = result.keys()
+        services = [dict(zip(keys, row)) for row in rows]
         session.close()
-        return result
+        return services
 
     def getServiceNamesByHostIPAndPort(self, host_ip, port):
         session = self.dbAdapter.session()
@@ -47,3 +51,9 @@ class ServiceRepository:
         result = session.execute(query, {'host_ip': str(host_ip), 'port': str(port)}).first()
         session.close()
         return result
+
+    def getServiceById(self, service_id):
+        session = self.dbAdapter.session()
+        service = session.query(serviceObj).filter_by(id=service_id).first()
+        session.close()
+        return service
