@@ -1,6 +1,6 @@
 """
-LEGION (https://gotham-security.com)
-Copyright (c) 2023 Gotham Security
+LEGION (https://shanewilliamscott.com)
+Copyright (c) 2025 Shane William Scott
 
     This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
     License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later
@@ -13,7 +13,7 @@ Copyright (c) 2023 Gotham Security
     You should have received a copy of the GNU General Public License along with this program.
     If not, see <http://www.gnu.org/licenses/>.
 
-Author(s): Shane Scott (sscott@gotham-security.com), Dmitriy Dubson (d.dubson@gmail.com)
+Author(s): Shane Scott (sscott@shanewilliamscott.com), Dmitriy Dubson (d.dubson@gmail.com)
 """
 import unittest
 from unittest import mock
@@ -85,7 +85,11 @@ class MyEventFilterTestCase(unittest.TestCase):
             self, hosts_table_view, selection_model, selected_row, mock_clipboard):
         expected_data = MagicMock()
         expected_data.toString = Mock(return_value="some clipboard data")
-        control_modifier = mock.patch.object(QApplication, 'keyboardModifiers', return_value=Qt.KeyboardModifier.ControlModifier)
+        control_modifier = mock.patch.object(
+            QApplication,
+            'keyboardModifiers',
+            return_value=Qt.KeyboardModifier.ControlModifier
+        )
         clipboard = mock.patch.object(QApplication, 'clipboard', return_value=mock_clipboard)
 
         self.mock_view.ui.HostsTableView = hosts_table_view
