@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 
 """
-LEGION (https://gotham-security.com)
-Copyright (c) 2023 Gotham Security
+LEGION (https://shanewilliamscott.com)
+Copyright (c) 2025 Shane William Scott
 
     This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
     License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later
@@ -14,6 +14,8 @@ Copyright (c) 2023 Gotham Security
 
     You should have received a copy of the GNU General Public License along with this program.
     If not, see <http://www.gnu.org/licenses/>.
+
+Author(s): Shane Scott (sscott@shanewilliamscott.com), Dmitriy Dubson (d.dubson@gmail.com)
 """
 
 import re
@@ -60,7 +62,10 @@ class CvesTableModel(QtCore.QAbstractTableModel):
         return resolveHeaders(role, orientation, section, self.__headers)
                 
     def data(self, index, role):  # this method takes care of how the information is displayed
-        if role == QtCore.Qt.ItemDataRole.DisplayRole or role == QtCore.Qt.ItemDataRole.EditRole:  # how to display each cell
+        if (
+            role == QtCore.Qt.ItemDataRole.DisplayRole
+            or role == QtCore.Qt.ItemDataRole.EditRole
+        ):  # how to display each cell
             row = index.row()
             column = index.column()
             return self.__cves[row][self.columnMapping[column]]
